@@ -13,8 +13,8 @@ import re
 import sys
 import sysconfig
 from collections import OrderedDict, namedtuple
+from distutils import dist
 from distutils.command.install import SCHEME_KEYS
-from distutils.dist import Distribution
 from string import digits
 
 VersionInfo = namedtuple("VersionInfo", ["major", "minor", "micro", "releaselevel", "serial"])
@@ -75,6 +75,15 @@ class PythonInfo(object):
         self.stdout_encoding = u(getattr(sys.stdout, "encoding", None))
 
         self.sysconfig_paths = {u(i): u(sysconfig.get_path(i, expand=False)) for i in sysconfig.get_path_names()}
+
+        self.sysconfig = {
+            u(k): u(v)
+            for k, v in [  # a list of content to store from sysconfig
+                ("makefile_filename", sysconfig.get_makefile_filename()),
+            ]
+            if k is not None
+        }
+
         config_var_keys = set()
         for element in self.sysconfig_paths.values():
             for k in _CONF_VAR_RE.findall(element):
@@ -110,7 +119,8 @@ class PythonInfo(object):
     @staticmethod
     def _distutils_install():
         # follow https://github.com/pypa/pip/blob/master/src/pip/_internal/locations.py#L95
-        d = Distribution({"script_args": "--no-user-cfg"})  # configuration files not parsed so they do not hijack paths
+        # note here we don't import Distribution directly to allow setuptools to patch it
+        d = dist.Distribution({"script_args": "--no-user-cfg"})  # conf files not parsed so they do not hijack paths
         if hasattr(sys, "_framework"):
             sys._framework = None  # disable macOS static paths for framework
         i = d.get_command_obj("install", create=True)
@@ -235,13 +245,19 @@ class PythonInfo(object):
 
     def satisfies(self, spec, impl_must_match):
         """check if a given specification can be satisfied by the this python interpreter instance"""
-        if spec.path and self.executable == os.path.abspath(spec.path):
-            return True  # if the path is a our own executable path we're done
-
-        if spec.path is not None:  # if path set, and is not our original executable name, this does not match
-            root, _ = os.path.splitext(os.path.basename(self.original_executable))
-            if root != spec.path:
-                return False
+        if spec.path:
+            if self.executable == os.path.abspath(spec.path):
+                return True  # if the path is a our own executable path we're done
+            if not spec.is_abs:
+                # if path set, and is not our original executable name, this does not match
+                basename = os.path.basename(self.original_executable)
+                spec_path = spec.path
+                if sys.platform == "win32":
+                    basename, suffix = os.path.splitext(basename)
+                    if spec_path.endswith(suffix):
+                        spec_path = spec_path[: -len(suffix)]
+                if basename != spec_path:
+                    return False
 
         if impl_must_match:
             if spec.implementation is not None and spec.implementation.lower() != self.implementation.lower():
@@ -297,7 +313,13 @@ class PythonInfo(object):
         proposed = from_exe(cls, app_data, exe, raise_on_error=raise_on_error, ignore_cache=ignore_cache)
         # noinspection PyProtectedMember
         if isinstance(proposed, PythonInfo) and resolve_to_host:
-            proposed = proposed._resolve_to_system(app_data, proposed)
+            try:
+                proposed = proposed._resolve_to_system(app_data, proposed)
+            except Exception as exception:
+                if raise_on_error:
+                    raise exception
+                logging.info("ignore %s due cannot resolve system due to %r", proposed.original_executable, exception)
+                proposed = None
         return proposed
 
     @classmethod
