@@ -2,28 +2,28 @@ from __future__ import absolute_import, unicode_literals
 
 BUNDLE_SUPPORT = {
     "3.9": {
-        "pip": "pip-20.0.2-py2.py3-none-any.whl",
-        "setuptools": "setuptools-46.1.1-py3-none-any.whl",
+        "pip": "pip-20.1-py2.py3-none-any.whl",
+        "setuptools": "setuptools-46.1.3-py3-none-any.whl",
         "wheel": "wheel-0.34.2-py2.py3-none-any.whl",
     },
     "3.8": {
-        "pip": "pip-20.0.2-py2.py3-none-any.whl",
-        "setuptools": "setuptools-46.1.1-py3-none-any.whl",
+        "pip": "pip-20.1-py2.py3-none-any.whl",
+        "setuptools": "setuptools-46.1.3-py3-none-any.whl",
         "wheel": "wheel-0.34.2-py2.py3-none-any.whl",
     },
     "3.7": {
-        "pip": "pip-20.0.2-py2.py3-none-any.whl",
-        "setuptools": "setuptools-46.1.1-py3-none-any.whl",
+        "pip": "pip-20.1-py2.py3-none-any.whl",
+        "setuptools": "setuptools-46.1.3-py3-none-any.whl",
         "wheel": "wheel-0.34.2-py2.py3-none-any.whl",
     },
     "3.6": {
-        "pip": "pip-20.0.2-py2.py3-none-any.whl",
-        "setuptools": "setuptools-46.1.1-py3-none-any.whl",
+        "pip": "pip-20.1-py2.py3-none-any.whl",
+        "setuptools": "setuptools-46.1.3-py3-none-any.whl",
         "wheel": "wheel-0.34.2-py2.py3-none-any.whl",
     },
     "3.5": {
-        "pip": "pip-20.0.2-py2.py3-none-any.whl",
-        "setuptools": "setuptools-46.1.1-py3-none-any.whl",
+        "pip": "pip-20.1-py2.py3-none-any.whl",
+        "setuptools": "setuptools-46.1.3-py3-none-any.whl",
         "wheel": "wheel-0.34.2-py2.py3-none-any.whl",
     },
     "3.4": {
@@ -32,7 +32,7 @@ BUNDLE_SUPPORT = {
         "wheel": "wheel-0.33.6-py2.py3-none-any.whl",
     },
     "2.7": {
-        "pip": "pip-20.0.2-py2.py3-none-any.whl",
+        "pip": "pip-20.1-py2.py3-none-any.whl",
         "setuptools": "setuptools-44.1.0-py2.py3-none-any.whl",
         "wheel": "wheel-0.34.2-py2.py3-none-any.whl",
     },
