@@ -12,6 +12,7 @@ import coverage
 import pytest
 import six
 
+from virtualenv.discovery.builtin import get_interpreter
 from virtualenv.discovery.py_info import PythonInfo
 from virtualenv.info import IS_PYPY, IS_WIN, fs_supports_symlink
 from virtualenv.report import LOGGER
@@ -24,6 +25,19 @@ def pytest_addoption(parser):
     parser.addoption("--int", action="store_true", default=False, help="run integration tests")
 
 
+def pytest_configure(config):
+    """Ensure randomly is called before we re-order"""
+    manager = config.pluginmanager
+    # noinspection PyProtectedMember
+    order = manager.hook.pytest_collection_modifyitems._nonwrappers
+    dest = next((i for i, p in enumerate(order) if p.plugin is manager.getplugin("randomly")), None)
+    if dest is not None:
+        from_pos = next(i for i, p in enumerate(order) if p.plugin is manager.getplugin(__file__))
+        temp = order[dest]
+        order[dest] = order[from_pos]
+        order[from_pos] = temp
+
+
 def pytest_collection_modifyitems(config, items):
     int_location = os.path.join("tests", "integration", "").rstrip()
     if len(items) == 1:
@@ -212,36 +226,25 @@ def coverage_env(monkeypatch, link):
 
 class EnableCoverage(object):
     _COV_FILE = Path(coverage.__file__)
-    _COV_SITE_PACKAGES = _COV_FILE.parents[1]
-    _ROOT_COV_FILES_AND_FOLDERS = [i for i in _COV_SITE_PACKAGES.iterdir() if i.name.startswith("coverage")]
-    _SUBPROCESS_TRIGGER_PTH_NAME = "coverage-virtual-sub.pth"
+    _ROOT_COV_FILES_AND_FOLDERS = [i for i in _COV_FILE.parents[1].iterdir() if i.name.startswith("coverage")]
 
     def __init__(self, link):
         self.link = link
         self.targets = []
-        self.cov_pth = self._COV_SITE_PACKAGES / self._SUBPROCESS_TRIGGER_PTH_NAME
 
     def __enter__(self, creator):
-        assert not self.cov_pth.exists()
         site_packages = creator.purelib
-        p_th = site_packages / self._SUBPROCESS_TRIGGER_PTH_NAME
-
-        if not str(p_th).startswith(str(self._COV_SITE_PACKAGES)):
-            p_th.write_text("import coverage; coverage.process_startup()")
-            self.targets.append((p_th, p_th.unlink))
-            for entry in self._ROOT_COV_FILES_AND_FOLDERS:
-                target = site_packages / entry.name
-                if not target.exists():
-                    clean = self.link(entry, target)
-                    self.targets.append((target, clean))
+        for entry in self._ROOT_COV_FILES_AND_FOLDERS:
+            target = site_packages / entry.name
+            if not target.exists():
+                clean = self.link(entry, target)
+                self.targets.append((target, clean))
         return self
 
     def __exit__(self, exc_type, exc_val, exc_tb):
-        assert self._COV_FILE.exists()
         for target, clean in self.targets:
             if target.exists():
                 clean()
-        assert not self.cov_pth.exists()
         assert self._COV_FILE.exists()
 
 
@@ -289,7 +292,7 @@ def current_fastest(current_creators):
 @pytest.fixture(scope="session")
 def session_app_data(tmp_path_factory):
     app_data = AppData(folder=str(tmp_path_factory.mktemp("session-app-data")))
-    with change_env_var("VIRTUALENV_OVERRIDE_APP_DATA", str(app_data.folder.path)):
+    with change_env_var(str("VIRTUALENV_OVERRIDE_APP_DATA"), str(app_data.folder.path)):
         yield app_data.folder
 
 
@@ -316,3 +319,15 @@ def temp_app_data(monkeypatch, tmp_path):
     app_data = tmp_path / "app-data"
     monkeypatch.setenv(str("VIRTUALENV_OVERRIDE_APP_DATA"), str(app_data))
     return app_data
+
+
+@pytest.fixture(scope="session")
+def cross_python(is_inside_ci, session_app_data):
+    spec = str(2 if sys.version_info[0] == 3 else 3)
+    interpreter = get_interpreter(spec, session_app_data)
+    if interpreter is None:
+        msg = "could not find {}".format(spec)
+        if is_inside_ci:
+            raise RuntimeError(msg)
+        pytest.skip(msg=msg)
+    yield interpreter
