@@ -7,6 +7,7 @@ import pytest
 
 from virtualenv.discovery.py_info import EXTENSIONS, PythonInfo
 from virtualenv.info import IS_WIN, fs_is_case_sensitive, fs_supports_symlink
+from virtualenv.util.path import Path
 
 CURRENT = PythonInfo.current()
 
@@ -16,11 +17,11 @@ def test_discover_empty_folder(tmp_path, monkeypatch, session_app_data):
         CURRENT.discover_exe(session_app_data, prefix=str(tmp_path))
 
 
-BASE = {CURRENT.distutils_install["scripts"], "."}
+BASE = (CURRENT.distutils_install["scripts"], ".")
 
 
 @pytest.mark.skipif(not fs_supports_symlink(), reason="symlink is not supported")
-@pytest.mark.parametrize("suffix", {".exe", ".cmd", ""} & set(EXTENSIONS) if IS_WIN else [""])
+@pytest.mark.parametrize("suffix", sorted({".exe", ".cmd", ""} & set(EXTENSIONS) if IS_WIN else [""]))
 @pytest.mark.parametrize("into", BASE)
 @pytest.mark.parametrize("arch", [CURRENT.architecture, ""])
 @pytest.mark.parametrize("version", [".".join(str(i) for i in CURRENT.version_info[0:i]) for i in range(3, 0, -1)])
@@ -31,6 +32,9 @@ def test_discover_ok(tmp_path, monkeypatch, suffix, impl, version, arch, into, c
     folder.mkdir(parents=True, exist_ok=True)
     dest = folder / "{}{}".format(impl, version, arch, suffix)
     os.symlink(CURRENT.executable, str(dest))
+    pyvenv = Path(CURRENT.executable).parents[1] / "pyvenv.cfg"
+    if pyvenv.exists():
+        (folder / pyvenv.name).write_text(pyvenv.read_text())
     inside_folder = str(tmp_path)
     base = CURRENT.discover_exe(session_app_data, inside_folder)
     found = base.executable
